<?xml version="1.0" encoding="UTF-8"?>
<!--
* ENRICH gBank viewer - the user-friendly interface showing the content of the gBank database.
* Copyright © 2009-2010 AiP Beroun s.r.o, Czech Republic
* Authors: Sergei Kostyukevich <sergej.kostjukevic@aipberoun.cz>, Tomas Psohlavec <tomas.psohlavec@aipberoun.cz>
* WEB: www.aipberoun.cz

* Content Creation: gBank sample content is based on the Medieval 
* Unicode Font Initiative Specification v. 3.0 http://www.mufi.info/ 
* with transformation to TEI by James Cummings <James.Cummings@oucs.ox.ac.uk>

* Font Creation: Font images based on Andron Scriptor Web font v. 3.0 by Andreas Stötzner.

* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.

* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.

* You should have received a copy of the GNU General Public License
* along with this program. If not, see http://www.gnu.org/licenses/gpl.html.
-->
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output indent="yes" encoding="UTF-8" method="xml" omit-xml-declaration="yes"/>

<xsl:template match="/TEI">
	<xsl:apply-templates select="teiHeader"/>
	<xsl:apply-templates select="text"/>
</xsl:template>

<xsl:template match="teiHeader">
	<xsl:apply-templates select="fileDesc"/>
	<div id="teiHeader">
		<div id="showSymbols">
			<xsl:apply-templates select="encodingDesc/charDecl"/>
		</div>
	</div>
	<div id="gBankFooter">
		<p><xsl:apply-templates select="fileDesc/sourceDesc"/></p>
		<p><xsl:apply-templates select="fileDesc/publicationStmt/availability"/></p>
	</div>
	<div class="gBankFooter">
		<xsl:apply-templates select="revisionDesc"/>
		<xsl:call-template name="valid"/>
	</div>
	<script type="text/javascript">
		<!--<xsl:apply-templates select="encodingDesc/charDecl/char" mode="js"/>-->
		<xsl:apply-templates select="encodingDesc/charDecl" mode="js"/>
	</script>
</xsl:template>
<xsl:template match="text"/>


<xsl:template match="charDecl">
	<div class="divShell">
		<xsl:variable name="dir_id" select="position()"/>  		
		<div class="dirName">
			<xsl:attribute name="id"><xsl:value-of select="concat('dirName', $dir_id)"/></xsl:attribute>			
			<xsl:call-template name="getDesc"/>
		</div>
		<div style="display:none;" class="dirSymbols">
			<xsl:attribute name="id"><xsl:value-of select="concat('dirSymbols', $dir_id)"/></xsl:attribute>			
			<xsl:apply-templates select="char"/>
		</div>
	</div>	
</xsl:template>
<xsl:template match="charDecl" mode="js">
	<xsl:call-template name="js_charDecl"/>
	<xsl:apply-templates select="char" mode="js"/>
</xsl:template>

<xsl:template name="getDesc">
<xsl:choose>
	<xsl:when test="string-length(desc)=0">
		<xsl:text>no character description available</xsl:text>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="desc"/>
	</xsl:otherwise>
</xsl:choose>
</xsl:template>	

<xsl:template match="char">
	<xsl:choose>
		<xsl:when test="graphic/@url != ''">
			<img>
				<xsl:attribute name="id"><xsl:value-of select="@xml:id"/></xsl:attribute>
				<xsl:attribute name="class">symbol</xsl:attribute>
				<xsl:attribute name="src"><xsl:value-of select="$ADD_REL_PATH"/><xsl:value-of select="$GBANK_GRAPHIC"/><xsl:value-of select="substring-after(graphic/@url, $GBANK_GRAPHIC_REMOVE_SUBDIR)"/></xsl:attribute>
				<xsl:attribute name="alt">
					<xsl:call-template name="getDesc"/>
				</xsl:attribute>
			</img>  
		</xsl:when>
		<xsl:otherwise>
			<div>
				<xsl:attribute name="id"><xsl:value-of select="@xml:id"/></xsl:attribute>
				<xsl:attribute name="class">noImgElement</xsl:attribute>
				<xsl:call-template name="getDesc"/>
			</div>		
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>
<xsl:template match="char" mode="js">
	<xsl:call-template name="js_char"/>		
</xsl:template>


<xsl:template name="js_char">
	<!-- definition of events for elements -->
	<xsl:text>document.getElementById("</xsl:text><xsl:value-of select="@xml:id"/><xsl:text>").onclick = elementOnClick;</xsl:text>
	<xsl:text>document.getElementById("</xsl:text><xsl:value-of select="@xml:id"/><xsl:text>").onmousemove =  function(e) {if(!e) e = event;elementOnMouseOver(this.id, e.clientX, e.clientY);
};</xsl:text>
	<xsl:text>document.getElementById("</xsl:text><xsl:value-of select="@xml:id"/><xsl:text>").onmouseout = elementOnMouseOut;</xsl:text>
	<!-- filling of the array of element propetries -->
	<xsl:variable name="charProp"><xsl:apply-templates select="charProp"/></xsl:variable>
	<xsl:variable name="mapping"><xsl:apply-templates select="mapping"/></xsl:variable>
	<xsl:text>arrayElem["</xsl:text><xsl:value-of select="@xml:id"/><xsl:text>"] = {charProp: [</xsl:text><xsl:value-of select="substring($charProp, 2)"/><xsl:text>], mapping: [</xsl:text><xsl:value-of select="substring($mapping, 2)"/><xsl:text>], note:"</xsl:text><xsl:value-of select="note"/><xsl:text>"};</xsl:text>
</xsl:template>
<xsl:template match="charProp">
	<xsl:text>,{"localName":"</xsl:text><xsl:value-of select="localName"/>
	<xsl:text>", "value":"</xsl:text><xsl:value-of select="value"/>
	<xsl:text>"}</xsl:text>
</xsl:template>
<xsl:template match="mapping">
	<xsl:text>,{"type":"</xsl:text>
	<xsl:value-of select="@type"/><xsl:text>", "subtype":"</xsl:text>
	<xsl:value-of select="@subtype"/><xsl:text>", "value":"</xsl:text>
	<xsl:choose>
		<xsl:when test=". != '&#34;'">
			<xsl:value-of select="." />
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\"</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>"}</xsl:text>
</xsl:template>
<xsl:template name="js_charDecl">
	<xsl:text>document.getElementById("dirName</xsl:text>
	<xsl:value-of select="position()"/>
	<xsl:text>").onclick = dirOnClick;</xsl:text>
	<xsl:text>document.getElementById("dirName</xsl:text>
	<xsl:value-of select="position()"/>
	<xsl:text>").onmouseover = dirOnMouseOver;</xsl:text>
	<xsl:text>document.getElementById("dirName</xsl:text>
	<xsl:value-of select="position()"/>
	<xsl:text>").onmouseout = dirOnMouseOut;</xsl:text>
</xsl:template>

<!-- About... -->	
<xsl:template match="fileDesc">
	<div id="gBankPublAndEditionStmt">
		<span class="label">Edition:</span>
		<xsl:text> </xsl:text><xsl:value-of select="editionStmt/edition/@n"/>
		<xsl:if test="text()">
			<xsl:text>; </xsl:text>
			<xsl:value-of select="editionStmt/edition/text()"/>
		</xsl:if>
		<xsl:apply-templates select="editionStmt/edition/date"/>
		<xsl:element name="br"/>
		<span class="label">Authority: </span>
		<xsl:apply-templates select="publicationStmt/authority"/>
		<xsl:element name="br"/>
		<span class="label">Distributor: </span>
		<xsl:apply-templates select="publicationStmt/distributor"/>
		<xsl:element name="br"/>
		<xsl:choose>
			<xsl:when test="string-length(publicationStmt/availability)=0">
				<span class="label">Availability status: </span>
				<xsl:value-of select="publicationStmt/availability/@status"/>
			</xsl:when>
		</xsl:choose>
	</div>
</xsl:template>

<xsl:template match="revisionDesc">
		<strong>Revision history:</strong>
		<xsl:element name="br"/>
		<ul>
			<xsl:apply-templates select="change"  mode="revision"><xsl:sort select="date/@when" order="descending"/></xsl:apply-templates>		
		</ul>	
</xsl:template>

<xsl:template match="change" mode="revision">
	<li>
		<xsl:apply-templates mode="revision"/>
	</li>
</xsl:template>

<xsl:template match="date">
	<xsl:value-of select="concat(substring(., 9, 2), '.', substring(., 6, 2), '.', substring(., 1, 4))"/>
</xsl:template>
<xsl:template match="date" mode="revision">
	<xsl:value-of select="concat(substring(@when, 9, 2), '.', substring(@when, 6, 2), '.', substring(@when, 1, 4))"/>
</xsl:template>
<xsl:template match="ref">
	<a><xsl:attribute name="href"><xsl:value-of select="@target"/></xsl:attribute><xsl:value-of select="."/></a>
</xsl:template>
<xsl:template match="persName">
	<span style="color:#9d0f0f;"><xsl:value-of select="."/></span>
</xsl:template>
<xsl:template match="persName" mode="revision">
	<span style="color:#9d0f0f;"><xsl:value-of select="."/></span>
</xsl:template>

<xsl:template name="valid">
		<div class="valid">
				<a href="http://validator.w3.org/check?uri=referer">
					<img style="border:0;width:88px;height:31px"
					src="http://www.w3.org/Icons/valid-xhtml10"
					alt="Valid XHTML 1.0 Strict"/></a>
				<a href="http://jigsaw.w3.org/css-validator/check/referer">
						<img style="border:0;width:88px;height:31px"
						src="http://www.w3.org/Icons/valid-css2"
						alt="Valid CSS!" />
				</a>
		</div>	
	</xsl:template>
		
</xsl:stylesheet>
